# Virtenviro - Your VIRTual ENVIROment

Open source content management system (CMS) based on the django framework.


## What is virtenviro

* [it's simple to start](#start)
* it's simple to use
* it's simple to extend

## Packages required

* 'Django 1.7+',
* 'django-mptt',
* 'pytils',
* 'lxml',
* 'Pillow',
* 'sorl-thumbnail',
* 'django-filebrowser-no-grappelli',


## How to install

```sh
pip install git+git://github.com/Haikson/virtenviro.git#virtenviro
```


## <a name="start"></a>START

## ToDo


* Create smart-forms application: smart forms constructor
* Gallery application
* Add User registration and authorisation
* Blogging functionality
* E-commerce application
* Create portfolio functionality as standalone app

## SHOP

### importing goods

 * simple xml format for virtenviro.shop . [Link]
 * do not forget set uwsgi_read_timeout longer. Improting is a long process/
 
## USES
[django-picklefield](https://github.com/shrubberysoft/django-picklefield) in project
